@@ -24,6 +24,8 @@ require 'fileutils'
 require 'uri'
 require 'nkf'
 require 'time'
+require 'zlib'
+require 'stringio'
 
 require 'const.rb'
 
@@ -87,11 +89,19 @@ module Downloader
 
     Net::HTTP.start(URI.parse(dat_url).host, 80) {|http|
       header = {
+        "Accept-Encoding" => "gzip",
         "User-Agent" => USER_AGENT
       }
       response = http.get(URI.parse(dat_url).path, header)
+      raise Net::ProtoRetriableError if response.code == '302'
 
-      raw_str = response.body
+      if response['Content-Encoding'] == "gzip" then
+        gzipped_str = response.body
+        gzipped_str_io = StringIO.new(gzipped_str)
+        raw_str = Zlib::GzipReader.new(gzipped_str_io).read
+      else
+        raw_str = response.body
+      end
       str = Util.to_utf8(raw_str, Util.board_type(dat_url))
 
       date = response['Date']
@@ -104,6 +114,37 @@ module Downloader
     str
   end
 
+  def self.download_maru(dat_url)
+    str = nil
+    date = nil
+    offlaw_path = Util.dat_url_to_offlaw_path(dat_url)
+
+    Net::HTTP.start(URI.parse(dat_url).host, 80) {|http|
+      header = {
+        "Accept-Encoding" => "gzip",
+        "User-Agent" => USER_AGENT
+      }
+      response = http.get(offlaw_path, header)
+
+      gzipped_str = response.body
+      gzipped_str_io = StringIO.new(gzipped_str)
+      raw_str = Zlib::GzipReader.new(gzipped_str_io).read
+      str = Util.to_utf8(raw_str, Util.board_type(dat_url))
+
+      # remove '+OK ..../1024K\tLocation: temp/\n'
+      index = str.index(/\n/)
+      str = str[index+1..-1]
+
+      date = response['Date']
+    }
+
+    dir = Util.dat_url_to_dat_dir_path(dat_url)
+    dat_file_name = Util.dat_url_to_dat_file_name(dat_url)
+    save_date(dir, dat_file_name + ".idx", date)
+    save(dir, dat_file_name, str)
+    str
+  end
+
   def self.load_dat(dat_url)
     dir = Util.dat_url_to_dat_dir_path(dat_url)
     dat_file_name = Util.dat_url_to_dat_file_name(dat_url)
