@@ -38,6 +38,6 @@ class ThreadInfo
     dir = Util.dat_url_to_dat_dir_path(@dat_url)
     config = KDE::Config.new(dir + "/" + dat_file_name + ".idx")
 
-    @read_num = config.readEntry("ResNum")
+    @read_num = config.readNumEntry("ResNum")
   end
 end
