@@ -21,8 +21,10 @@
 
 class ThreadView < Qt::Widget
   slots 'reload()'
+  slots 'delete()'
   slots 'show_write_dialog()'
   slots 'remove_self()'
+  slots 'search()'
 
   attr_reader :dat_url
 
@@ -40,12 +42,23 @@ class ThreadView < Qt::Widget
     buttons_layout.addWidget(@write_button)
     connect(@write_button, SIGNAL("clicked()"), self, SLOT("show_write_dialog()"))
 
+    @search_line = Qt::LineEdit.new(self)
+    @search_line.setEnabled(false)
+    buttons_layout.addWidget(@search_line)
+    connect(@search_line, SIGNAL("returnPressed()"), self, SLOT("search()"))
+
     @reload_button = Qt::ToolButton.new(self)
     @reload_button.setPixmap(KDE::SmallIcon("reload"))
     @reload_button.setEnabled(false)
     buttons_layout.addWidget(@reload_button)
     connect(@reload_button, SIGNAL("clicked()"), self, SLOT("reload()"))
 
+    @delete_button = Qt::ToolButton.new(self)
+    @delete_button.setPixmap(KDE::SmallIcon("edittrash"))
+    @delete_button.setEnabled(false)
+    buttons_layout.addWidget(@delete_button)
+    connect(@delete_button, SIGNAL("clicked()"), self, SLOT("delete()"))
+
     spacer = Qt::SpacerItem.new(30, 20,
                                 Qt::SizePolicy::Expanding,
                                 Qt::SizePolicy::Minimum)
@@ -91,7 +104,9 @@ class ThreadView < Qt::Widget
 
   def enable_buttons
     @write_button.setEnabled(true)
+    @search_line.setEnabled(true)
     @reload_button.setEnabled(true)
+    @delete_button.setEnabled(true)
     @close_button.setEnabled(true)
   end
 
@@ -102,6 +117,17 @@ class ThreadView < Qt::Widget
     write(dat)
   end
 
+  def delete
+    if Qt::MessageBox::warning(self,
+                               "Kita",
+                               "スレッドのログを削除します。よろしいですか？",
+                               Qt::MessageBox::Ok,
+                               Qt::MessageBox::Cancel | Qt::MessageBox::Default) ==
+      Qt::MessageBox::Ok then
+      DatManager::delete_dat(@dat_url)
+    end
+  end
+
   def show_write_dialog
     dialog = WriteDialog.instance
     dialog.dat_url = @dat_url
@@ -136,4 +162,30 @@ class ThreadView < Qt::Widget
     clipboard = Qt::Application.clipboard
     clipboard.setText(selected_text, Qt::Clipboard::Clipboard)
   end
+
+  def search
+    str = @search_line.text
+    if str == @prev_search_text
+      search_next
+    elsif str != ""
+      search_new(str)
+      @prev_search_text = str
+    else
+      search_clear
+    end
+  end
+
+  def search_next
+    @html_part.findTextNext()
+    @search_line.setFocus()
+  end
+
+  def search_new(str)
+    @html_part.findTextBegin()
+    @html_part.findText(str, 0)
+  end
+
+  def search_clear
+    @html_part.findTextBegin()
+  end
 end
