@@ -117,7 +117,7 @@ module Util
     str += "&mail=" + CGI.escape(NKF.nkf("-Wsx", mail)) # UTF-8 -> SJIS with JISX0201
     str += "&MESSAGE=" + CGI.escape(NKF.nkf("-Wsx", body)) # UTF-8 -> SJIS with JISX0201
     str += "&bbs=" + board_id
-    str += "&hana=mogera"
+    str += Config.instance.post_str_append
     str += "&key=" + thread_id
     str += "&time=" + server_time.to_i.to_s
     str += "&sid=" + session_id if session_id
